import { PublicKey } from '@solana/web3.js';
import * as RaceCore from '@race-foundation/sdk-core';
import { VoteType, EntryType } from '@race-foundation/sdk-core';
export interface IPlayerState {
    isInitialized: boolean;
    nick: string;
    pfpKey?: PublicKey;
}
export interface IPlayerJoin {
    key: PublicKey;
    balance: bigint;
    position: number;
    accessVersion: bigint;
    verifyKey: string;
}
export interface IServerJoin {
    key: PublicKey;
    endpoint: string;
    accessVersion: bigint;
    verifyKey: string;
}
export interface IVote {
    voterKey: PublicKey;
    voteeKey: PublicKey;
    voteType: VoteType;
}
export interface IGameReg {
    title: string;
    gameKey: PublicKey;
    bundleKey: PublicKey;
    regTime: bigint;
}
export interface IRegistryState {
    isInitialized: boolean;
    isPrivate: boolean;
    size: number;
    ownerKey: PublicKey;
    games: IGameReg[];
}
export interface IGameState {
    isInitialized: boolean;
    title: string;
    bundleKey: PublicKey;
    stakeKey: PublicKey;
    ownerKey: PublicKey;
    tokenKey: PublicKey;
    transactorKey: PublicKey | undefined;
    accessVersion: bigint;
    settleVersion: bigint;
    maxPlayers: number;
    players: IPlayerJoin[];
    servers: IServerJoin[];
    dataLen: number;
    data: Uint8Array;
    votes: IVote[];
    unlockTime: bigint | undefined;
    entryType: EntryType;
    recipientAddr: PublicKey;
}
export interface IServerState {
    isInitialized: boolean;
    key: PublicKey;
    ownerKey: PublicKey;
    endpoint: string;
}
export interface IRecipientState {
    readonly addr: PublicKey;
    readonly capAddr: PublicKey | undefined;
    readonly slots: IRecipientSlot[];
}
declare const RECIPIENT_SLOT_TYPE: {
    readonly Nft: 0;
    readonly Token: 1;
};
type RecipientSlotType = (typeof RECIPIENT_SLOT_TYPE)[keyof typeof RECIPIENT_SLOT_TYPE];
export interface IRecipientSlot {
    readonly id: number;
    readonly slotType: RecipientSlotType;
    readonly tokenAddr: PublicKey;
    readonly stakeAddr: PublicKey;
    readonly shares: IRecipientSlotShare[];
}
export interface IRecipientSlotShare {
    readonly owner: RecipientSlotOwner;
    readonly weights: number;
    readonly claimAmount: bigint;
    readonly claimAmountCap: bigint;
}
export declare class PlayerState implements IPlayerState {
    isInitialized: boolean;
    nick: string;
    pfpKey?: PublicKey;
    constructor(fields: IPlayerState);
    serialize(): Uint8Array;
    static deserialize(data: Uint8Array): PlayerState;
    generalize(addr: PublicKey): RaceCore.PlayerProfile;
}
export declare class Vote implements IVote {
    voterKey: PublicKey;
    voteeKey: PublicKey;
    voteType: VoteType;
    constructor(fields: IVote);
    generalize(): RaceCore.Vote;
}
export declare class ServerJoin implements IServerJoin {
    key: PublicKey;
    endpoint: string;
    accessVersion: bigint;
    verifyKey: string;
    constructor(fields: IServerJoin);
    generalize(): RaceCore.ServerJoin;
}
export declare class PlayerJoin implements IPlayerJoin {
    key: PublicKey;
    balance: bigint;
    position: number;
    accessVersion: bigint;
    verifyKey: string;
    constructor(fields: IPlayerJoin);
    generalize(): RaceCore.PlayerJoin;
}
export declare class GameState implements IGameState {
    isInitialized: boolean;
    title: string;
    bundleKey: PublicKey;
    stakeKey: PublicKey;
    ownerKey: PublicKey;
    tokenKey: PublicKey;
    transactorKey: PublicKey | undefined;
    accessVersion: bigint;
    settleVersion: bigint;
    maxPlayers: number;
    players: PlayerJoin[];
    servers: ServerJoin[];
    dataLen: number;
    data: Uint8Array;
    votes: Vote[];
    unlockTime: bigint | undefined;
    entryType: EntryType;
    recipientAddr: PublicKey;
    constructor(fields: IGameState);
    serialize(): Uint8Array;
    static deserialize(data: Uint8Array): GameState;
    generalize(addr: PublicKey): RaceCore.GameAccount;
}
export declare class GameReg implements IGameReg {
    title: string;
    gameKey: PublicKey;
    bundleKey: PublicKey;
    regTime: bigint;
    constructor(fields: IGameReg);
    generalize(): RaceCore.GameRegistration;
}
export declare class RegistryState implements IRegistryState {
    isInitialized: boolean;
    isPrivate: boolean;
    size: number;
    ownerKey: PublicKey;
    games: GameReg[];
    constructor(fields: IRegistryState);
    serialize(): Uint8Array;
    static deserialize(data: Uint8Array): RegistryState;
    generalize(addr: PublicKey): RaceCore.RegistrationAccount;
}
export declare class ServerState implements IServerState {
    isInitialized: boolean;
    key: PublicKey;
    ownerKey: PublicKey;
    endpoint: string;
    constructor(fields: IServerState);
    serialize(): Uint8Array;
    static deserialize(data: Uint8Array): ServerState;
    generalize(): RaceCore.ServerAccount;
}
export declare abstract class RecipientSlotOwner {
}
export declare class RecipientSlotOwnerUnassigned extends RecipientSlotOwner {
    identifier: string;
    constructor(fields: any);
}
export declare class RecipientSlotOwnerAssigned extends RecipientSlotOwner {
    addr: PublicKey;
    constructor(fields: any);
}
export declare class RecipientSlotShare implements IRecipientSlotShare {
    owner: RecipientSlotOwner;
    weights: number;
    claimAmount: bigint;
    claimAmountCap: bigint;
    constructor(fields: IRecipientSlotShare);
    generalize(): RaceCore.RecipientSlotShare;
}
export declare class RecipientSlot implements IRecipientSlot {
    id: number;
    slotType: RecipientSlotType;
    tokenAddr: PublicKey;
    stakeAddr: PublicKey;
    shares: RecipientSlotShare[];
    constructor(fields: IRecipientSlot);
    generalize(): RaceCore.RecipientSlot;
}
export declare class RecipientState implements IRecipientState {
    addr: PublicKey;
    capAddr: PublicKey | undefined;
    slots: RecipientSlot[];
    constructor(fields: IRecipientState);
    serialize(): Uint8Array;
    static deserialize(data: Uint8Array): RecipientState;
    generalize(): RaceCore.RecipientAccount;
}
export {};
